#!/usr/bin/env ruby
# RUBY PROGRAM _________________________________________________ vim:sw=4:tw=79
#
# *      project : 
# *       author : Jakob Schmid
# *    commenced : 2008-05-19
# * last changes : 2008-06-23
# *        notes :
# *   references : 
# _____________________________________________________________________________

CONFIGURATION_FILE = ENV['HOME'] + "/.jmrc"

require 'xmpp4r/client'
require 'getoptlong'
require 'yaml'   # for serialization and deserialization of configuration
require 'socket' # for gethostname
include Jabber

$verbose = false
$configuration = {
    :sender_account          => 'USERNAME@SERVER/RESOURCE',
    :sender_account_password => 'PASSWORD',
    :receiver_account        => 'USERNAME@SERVER' 
}

class JabberClient
    def initialize(account, password)
	@client = Client::new(JID::new(account))
	@client.connect
	@client.auth(password)
    end

    def disconnect()
    end

    def send_message(receiver, message)
	message = Message::new(receiver, message).set_type(:normal).set_id('1')
	message.set_subject('')
	@client.send(message)
    end
end

def print_usage
      # puts "1234567890123456789012345678901234567890123456789012345678901234567890"
        puts "Usage: jm.rb [CONTACT] [MESSAGE]"
        puts
        puts "Send instant message using XMPP (Jabber). If message is omitted,"
        puts "message is read from stdin."
	puts "CONTACT is something like someone@somewhere.org"
        puts
        puts "Options:"
        puts "  -h, --help       this help message"
        puts "  -v, --verbose    verbose output"
end

def load_config
    if File.exists?(CONFIGURATION_FILE) then
        puts "#{CONFIGURATION_FILE} exists. Loading configuration..." if $verbose
        $configuration = YAML::load_file(CONFIGURATION_FILE)
        puts "ok." if $verbose
    else
        File.open(CONFIGURATION_FILE, 'w') do |out|
            puts "creating #{CONFIGURATION_FILE}..." if $verbose
            YAML.dump($configuration, out)
            puts "done." if $verbose
        end
    end
end

# parse command-line args
opts = GetoptLong.new(
   [ '--help',       '-h', GetoptLong::NO_ARGUMENT ],
   [ '--verbose',    '-v', GetoptLong::NO_ARGUMENT ]
)
opts.each do |opt, arg|
    case opt
    when '--verbose'
        $verbose = true
    when '--help'
        print_usage()
        exit
    end
end

load_config()
client = JabberClient.new($configuration[:sender_account], $configuration[:sender_account_password]);
message = Socket::gethostname + ":\n"
case ARGV.length
when 2
    message += ARGV[1]
    receiver = ARGV[0]
when 1
    message += ARGV[0]
    receiver = $configuration[:receiver_account]
else
    while line=gets
	message += line
    end
    receiver = $configuration[:receiver_account]
end
client.send_message(receiver, message)
client.disconnect()
